@@ -12,34 +12,46 @@ use Moose::Util::TypeConstraints;
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.20';
+our $VERSION = '0.30';
 
-has file => (is => 'ro', lazy => 1, default => sub {
-    my $self = shift;
-    my $meth = ($self->context || 'local') . '_file';
-    return $self->sqitch->config->$meth;
-});
+has file => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub {
+        my $self = shift;
+        my $meth = ( $self->context || 'local' ) . '_file';
+        return $self->sqitch->config->$meth;
+    }
+);
 
-has action  => (is => 'ro', isa => enum([qw(
-    get
-    get-all
-    get-regex
-    set
-    unset
-    list
-    edit
-    add
-    replace-all
-    unset-all
-    rename-section
-    remove-section
-)]));
-has context => (is => 'ro', isa => maybe_type enum([qw(
-    local
-    user
-    system
-)]));
-has type => (is => 'ro', isa => enum([qw(int num bool bool-or-int)]));
+has action => (
+    is  => 'ro',
+    isa => enum([qw(
+        get
+        get-all
+        get-regex
+        set
+        unset
+        list
+        edit
+        add
+        replace-all
+        unset-all
+        rename-section
+        remove-section
+    )]),
+);
+
+has context => (
+    is  => 'ro',
+    isa => maybe_type enum([qw(
+        local
+        user
+        system
+    )]),
+);
+
+has type => ( is => 'ro', isa => enum( [qw(int num bool bool-or-int)] ) );
 
 sub options {
     return qw(
@@ -68,10 +80,10 @@ sub options {
 }
 
 sub configure {
-    my ($class, $config, $opt) = @_;
+    my ( $class, $config, $opt ) = @_;
 
     # Make sure we are accessing only one file.
-    my @file = grep { $opt->{$_} }  qw(local user system file);
+    my @file = grep { $opt->{$_} } qw(local user system file);
     $class->usage('Only one config file at a time.') if @file > 1;
 
     # Make sure we have only one type.
@@ -99,25 +111,25 @@ sub configure {
 
     # Make it so.
     return {
-        ($action[0]   ? (action  => $action[0])   : ()),
-        ($type[0]     ? (type    => $type[0])     : ()),
-        ($context     ? (context => $context)     : ()),
-        ($opt->{file} ? (file    => $opt->{file}) : ()),
+        ( $action[0]   ? ( action  => $action[0] )   : () ),
+        ( $type[0]     ? ( type    => $type[0] )     : () ),
+        ( $context     ? ( context => $context )     : () ),
+        ( $opt->{file} ? ( file    => $opt->{file} ) : () ),
     };
 }
 
 sub execute {
     my $self = shift;
-    my $action = $self->action || (@_ > 1 ? 'set' : 'get');
+    my $action = $self->action || ( @_ > 1 ? 'set' : 'get' );
     $action =~ s/-/_/g;
     my $meth = $self->can($action)
         or die 'No method defined for ', $self->action, ' action';
 
-    return $self->$meth(@_)
+    return $self->$meth(@_);
 }
 
 sub get {
-    my ($self, $key, $rx) = @_;
+    my ( $self, $key, $rx ) = @_;
     $self->usage('Wrong number of arguments.') if !defined $key || $key eq '';
 
     my $val = try {
@@ -127,7 +139,8 @@ sub get {
             as     => $self->type,
             human  => 1,
         );
-    } catch {
+    }
+    catch {
         $self->fail(qq{More then one value for the key "$key"})
             if /^\QMultiple values/i;
         $self->fail($_);
@@ -139,7 +152,7 @@ sub get {
 }
 
 sub get_all {
-    my ($self, $key, $rx) = @_;
+    my ( $self, $key, $rx ) = @_;
     $self->usage('Wrong number of arguments.') if !defined $key || $key eq '';
 
     my @vals = try {
@@ -149,65 +162,68 @@ sub get_all {
             as     => $self->type,
             human  => 1,
         );
-    } catch {
+    }
+    catch {
         $self->fail($_);
     };
     $self->unfound unless @vals;
-    $self->emit(join $/, @vals);
+    $self->emit( join $/, @vals );
     return $self;
 }
 
 sub get_regex {
-    my ($self, $key, $rx) = @_;
+    my ( $self, $key, $rx ) = @_;
     $self->usage('Wrong number of arguments.') if !defined $key || $key eq '';
 
     my $config = $self->sqitch->config;
-    my %vals = try {
+    my %vals   = try {
         $config->get_regexp(
             key    => $key,
             filter => $rx,
             as     => $self->type,
             human  => 1,
         );
-    } catch {
+    }
+    catch {
         $self->fail($_);
     };
     $self->unfound unless %vals;
     my @out;
-    for my $key (sort keys %vals) {
-        if (defined $vals{$key}) {
+    for my $key ( sort keys %vals ) {
+        if ( defined $vals{$key} ) {
             if ( $config->is_multiple($key) ) {
-                push @out => "$key=[" . join(', ', @{$vals{$key}}) . ']';
+                push @out => "$key=[" . join( ', ', @{ $vals{$key} } ) . ']';
             }
             else {
                 push @out => "$key=$vals{$key}";
             }
-        } else {
+        }
+        else {
             push @out => $key;
         }
     }
-    $self->emit(join $/ => @out);
+    $self->emit( join $/ => @out );
 
     return $self;
 }
 
 sub set {
-    my ($self, $key, $value, $rx) = @_;
-    $self->_set($key, $value, $rx, multiple => 0);
+    my ( $self, $key, $value, $rx ) = @_;
+    $self->_set( $key, $value, $rx, multiple => 0 );
 }
 
 sub add {
-    my ($self, $key, $value) = @_;
-    $self->_set($key, $value, undef, multiple => 1);
+    my ( $self, $key, $value ) = @_;
+    $self->_set( $key, $value, undef, multiple => 1 );
 }
 
 sub replace_all {
-    my ($self, $key, $value, $rx) = @_;
-    $self->_set($key, $value, $rx, multiple => 1, replace_all => 1);
+    my ( $self, $key, $value, $rx ) = @_;
+    $self->_set( $key, $value, $rx, multiple => 1, replace_all => 1 );
 }
 
 sub _set {
-    my ($self, $key, $value, $rx, @p) = @_;
+    my ( $self, $key, $value, $rx, @p ) = @_;
     $self->usage('Wrong number of arguments.')
         if !defined $key || $key eq '' || !defined $value;
 
@@ -221,7 +237,8 @@ sub _set {
             as       => $self->type,
             @p,
         );
-    } catch {
+    }
+    catch {
         $self->fail('Cannot overwrite multiple values with a single value')
             if /^Multiple occurrences/i;
         $self->fail($_);
@@ -238,7 +255,7 @@ sub _file_config {
 }
 
 sub unset {
-    my ($self, $key, $rx) = @_;
+    my ( $self, $key, $rx ) = @_;
     $self->usage('Wrong number of arguments.') if !defined $key || $key eq '';
     $self->_touch_dir;
 
@@ -249,7 +266,8 @@ sub unset {
             filter   => $rx,
             multiple => 0,
         );
-    } catch {
+    }
+    catch {
         $self->fail('Cannot unset key with multiple values')
             if /^Multiple occurrences/i;
         $self->fail($_);
@@ -258,7 +276,7 @@ sub unset {
 }
 
 sub unset_all {
-    my ($self, $key, $rx) = @_;
+    my ( $self, $key, $rx ) = @_;
     $self->usage('Wrong number of arguments.') if !defined $key || $key eq '';
 
     $self->_touch_dir;
@@ -276,24 +294,22 @@ sub list {
     my $config = $self->context
         ? $self->_file_config
         : $self->sqitch->config;
-    $self->emit(scalar $config->dump) if $config;
+    $self->emit( scalar $config->dump ) if $config;
     return $self;
 }
 
 sub edit {
     my $self = shift;
+
     # Let the editor deal with locking.
-    $self->do_system($self->sqitch->editor, $self->file) or $self->fail;
+    $self->run( $self->sqitch->editor, $self->file );
 }
 
 sub rename_section {
-    my ($self, $old_name, $new_name) = @_;
-    unless (
-           defined $old_name && $old_name ne ''
-        && defined $new_name && $new_name ne ''
-    ) {
-        $self->usage('Wrong number of arguments.');
-    }
+    my ( $self, $old_name, $new_name ) = @_;
+    $self->usage('Wrong number of arguments.')
+        unless defined $old_name && $old_name ne ''
+            && defined $new_name && $new_name ne '';
 
     try {
         $self->sqitch->config->rename_section(
@@ -301,7 +317,8 @@ sub rename_section {
             to       => $new_name,
             filename => $self->file
         );
-    } catch {
+    }
+    catch {
         $self->fail('No such section!') if /\Qno such section/i;
         $self->fail($_);
     };
@@ -309,7 +326,7 @@ sub rename_section {
 }
 
 sub remove_section {
-    my ($self, $section) = @_;
+    my ( $self, $section ) = @_;
     $self->usage('Wrong number of arguments.')
         unless defined $section && $section ne '';
     try {
@@ -317,7 +334,8 @@ sub remove_section {
             section  => $section,
             filename => $self->file
         );
-    } catch {
+    }
+    catch {
         $self->fail('No such section!') if /\Qno such section/i;
         die $_;
     };
@@ -326,10 +344,10 @@ sub remove_section {
 
 sub _touch_dir {
     my $self = shift;
-    unless (-e $self->file) {
+    unless ( -e $self->file ) {
         require File::Basename;
-        my $dir = File::Basename::dirname($self->file);
-        unless (-e $dir && -d _) {
+        my $dir = File::Basename::dirname( $self->file );
+        unless ( -e $dir && -d _ ) {
             require File::Path;
             File::Path::make_path($dir);
         }
